#!/bin/bash
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://public.eu-egee.org/partners/ for details on 
# the copyright holders.
# For license conditions see the license file or
# http://eu-egee.org/license.html
#
# Authors: 
#      Akos Frohner <Akos.Frohner@cern.ch>
#
# This script is a userspace installation of the gLite configuration.
# It installs the system to a specified location using RPMs from the 
# gLite integration build (or local build directory) and some external 
# runtime dependency RPMs from the gLite external repository.
# 
# The default installation location is in AFS.


# set GLITE_APT_REPOSITORY to override
DEFAULT_APT_REPOSITORY='rpm http://glitesoft.cern.ch/EGEE/gLite/APT/R3.0/ rhel30 externals Release3.0 updates'
# pass a directory on the command line to override
INSTALLROOT=/tmp/glite-ui

USAGE="$0 [--help] [userspace_install_dir]"

# working directory
cd $(dirname $0)
ADMINDIR=$PWD


# default flags
do_remove=no
do_install=yes

TEMP=$(getopt -o hnd --long none,help,remove,install,dryrun -- "$@")
eval set -- "$TEMP"

while true; do
    case "$1" in
        --remove)
            do_remove=yes
            shift
            ;;
        --install)
            do_install=yes
            shift
            ;;
        --dryrun)
            DRYRUN=echo
            shift
            ;;
        -h|--help)
            echo $USAGE
            exit
            ;;
        --)
            # end of options
            shift
            break
            ;;
        *)
            echo "Error: unknown option '$1'"
            echo $USAGE
            exit 1
    esac
done

# replacing the default install directory, if specified
if [ -n "$1" ]; then
    INSTALLROOT="$1"
fi


##############################################################################
# main
######

echo "Installing packages to '$INSTALLROOT'"

if [ "$do_remove" == 'yes' ]; then
    # removing old stuff
    rm -rf $INSTALLROOT/*

    # re-creating the directories
    mkdir -p $INSTALLROOT
    case $INSTALLROOT in
        /afs/*)
            fs setacl -dir $INSTALLROOT -acl system:anyuser rl
            ;;
    esac
fi

if [ "$do_install" == 'yes' ]; then
    # preparing the 'root' environment
    $DRYRUN mkdir -p $INSTALLROOT/root
    export HOME="$INSTALLROOT/root"
    
    # script install
    mkdir -p $HOME/bin
    cp $ADMINDIR/glite-userspace-rpm $HOME/bin/
    cp $ADMINDIR/glite-userspace-apt $HOME/bin/
    cd $HOME/bin
    ln -f -s glite-userspace-apt glite-userspace-apt-get
    ln -f -s glite-userspace-apt glite-userspace-apt-cache
    ln -f -s glite-userspace-apt glite-userspace-apt-config
    
    cat >$HOME/env_settings <<EOF
export GLITE_ROOT='$INSTALLROOT'
export HOME="\$GLITE_ROOT/root"
export LD_LIBRARY_PATH="\$GLITE_ROOT/usr/lib:\$LD_LIBRARY_PATH"
export PATH="\$GLITE_ROOT/root/bin:$PATH"
export PS1="root@glite:\w# "
alias apt-get=glite-userspace-apt-get
alias apt-cache=glite-userspace-apt-cache
alias apt-config=glite-userspace-apt-config
alias rpm=glite-userspace-rpm
cd
EOF
    # using the convenience aliases
    source $HOME/env_settings

    # start rpm once, to get it going
    glite-userspace-rpm -q rpm

    # empty call to initialize apt config
    glite-userspace-apt-cache show apt
    # get the list of packages
    mkdir -p $GLITE_ROOT/etc/apt/sources.list.d
    echo ${GLITE_APT_REPOSITORY:-$DEFAULT_APT_REPOSITORY} >$GLITE_ROOT/etc/apt/sources.list.d/glite-userspace.list
    glite-userspace-apt-get update

    # the envinorment script for bash
    cat >$GLITE_ROOT/env_settings.sh <<EOF
export GLITE_ROOT=$GLITE_ROOT
export PS1='\h@glite:\w> '
for bindir in \$(find $GLITE_ROOT -type d -name bin); do
    if [ -z "\$PATH" ]; then
        PATH=\$bindir
    else
        PATH=\$bindir:\$PATH
    fi
done
for libdir in \$(find $GLITE_ROOT -type d -name lib); do
    if [ -z "\$LD_LIBRARY_PATH" ]; then
        LD_LIBRARY_PATH=\$libdir
    else
        LD_LIBRARY_PATH=\$libdir:\$LD_LIBRARY_PATH
    fi
done
export PATH LD_LIBRARY_PATH
EOF
    chmod +x $GLITE_ROOT/env_settings.sh

    # the envinorment script for csh
    cat >$GLITE_ROOT/env_settings.csh <<EOF
setenv GLITE_ROOT $GLITE_ROOT
setenv PS1 '\h@glite:\w> '
EOF
    chmod +x $GLITE_ROOT/env_settings.sh

    # generating the documentation
    cat >$GLITE_ROOT/README <<EOF
gLite userspace installation at $GLITE_ROOT

Usage
=====

as a bash users
--------------
    bash --rcfile $GLITE_ROOT/env_settings.sh
  or
    source $GLITE_ROOT/root/env_settings.sh


as a tcsh users
--------------
    source $GLITE_ROOT/root/env_settings.csh


as the admin user
------------------
    bash --rcfile $GLITE_ROOT/root/env_settings
  or
    source $GLITE_ROOT/root/env_settings

for example you can do:
    glite-userspace-apt-get update
    glite-userspace-apt-get install ca_policy_eugridpma
    glite-userspace-apt-get install glite-ui-config
    glite-userspace-apt-get clean

The message 'Warning: / relocation for' warns about some 
massive relocation of a package. In general it is better
to install these packages separately (e.g. CA RPMs)!

EOF

    echo "See $GLITE_ROOT/README on how to use this installation!"
fi
